@@ -3,6 +3,8 @@ from .singlecore import SingleCoreSampler
 import numpy as np
 import random
 import logging
+import cloudpickle as pickle
+from jabbar import jabbar
 from .multicorebase import MultiCoreSampler, get_if_worker_healthy
 
 
@@ -20,6 +22,10 @@ def feed(feed_q, n_jobs, n_proc):
 
 
 def work(feed_q, result_q, simulate_one, max_eval, single_core_sampler):
+    # unwrap arguments
+    if isinstance(simulate_one, bytes):
+        simulate_one = pickle.loads(simulate_one)
+
     random.seed()
     np.random.seed()
 
@@ -51,12 +57,11 @@ class MulticoreParticleParallelSampler(MultiCoreSampler):
     However, if your summary statistics are large numpy arrays
     or similar, this could cause overhead
 
-
     Parameters
     ----------
-        n_procs: int, optional
-            If set to None, the Number of cores is determined according to
-            :func:`pyabc.sge.nr_cores_available`.
+    n_procs: int, optional
+        If set to None, the Number of cores is determined according to
+        :func:`pyabc.sge.nr_cores_available`.
 
 
     .. warning::
@@ -67,7 +72,8 @@ class MulticoreParticleParallelSampler(MultiCoreSampler):
     """
 
     def sample_until_n_accepted(
-            self, n, simulate_one, max_eval=np.inf, all_accepted=False):
+            self, n, simulate_one, max_eval=np.inf, all_accepted=False,
+            show_progress=False):
         # starting more than n jobs
         # does not help in this parallelization scheme
         n_procs = min(n, self.n_procs)
@@ -84,10 +90,12 @@ class MulticoreParticleParallelSampler(MultiCoreSampler):
         # the max_eval handling in this sampler is certainly not optimal
         single_core_sampler.sample_factory = self.sample_factory
 
-        worker_processes = [Process(target=work, args=(feed_q, result_q,
-                                                       simulate_one,
-                                                       max_eval,
-                                                       single_core_sampler))
+        # wrap arguments
+        if self.pickle:
+            simulate_one = pickle.dumps(simulate_one)
+        args = (feed_q, result_q, simulate_one, max_eval, single_core_sampler)
+
+        worker_processes = [Process(target=work, args=args)
                             for _ in range(n_procs)]
 
         for proc in worker_processes:
@@ -97,7 +105,7 @@ class MulticoreParticleParallelSampler(MultiCoreSampler):
 
         collected_results = []
 
-        for _ in range(n):
+        for _ in jabbar(range(n), enable=show_progress, keep=False):
             res = get_if_worker_healthy(worker_processes, result_q)
             collected_results.append(res)
 
