@@ -3,6 +3,9 @@ from ctypes import c_longlong
 from .multicorebase import MultiCoreSampler
 import numpy as np
 import random
+import cloudpickle as pickle
+from jabbar import jabbar
+
 from .multicorebase import get_if_worker_healthy
 
 DONE = "Done"
@@ -17,6 +20,10 @@ def work(simulate_one,
          max_eval: int,
          all_accepted: bool,
          sample_factory):
+    # unwrap arguments
+    if isinstance(simulate_one, bytes):
+        simulate_one = pickle.loads(simulate_one)
+
     random.seed()
     np.random.seed()
 
@@ -83,7 +90,8 @@ class MulticoreEvalParallelSampler(MultiCoreSampler):
     """
 
     def sample_until_n_accepted(
-            self, n, simulate_one, max_eval=np.inf, all_accepted=False):
+            self, n, simulate_one, max_eval=np.inf, all_accepted=False,
+            show_progress=False):
         n_eval = Value(c_longlong)
         n_eval.value = 0
 
@@ -92,15 +100,16 @@ class MulticoreEvalParallelSampler(MultiCoreSampler):
 
         queue = Queue()
 
-        processes = [
-            Process(target=work,
-                    args=(simulate_one, queue,
-                          n_eval, n_acc, n,
-                          self.check_max_eval, max_eval, all_accepted,
-                          self._create_empty_sample),
-                    daemon=self.daemon)
-            for _ in range(self.n_procs)
-        ]
+        # wrap arguments
+        if self.pickle:
+            simulate_one = pickle.dumps(simulate_one)
+        args = (simulate_one, queue,
+                n_eval, n_acc, n,
+                self.check_max_eval, max_eval, all_accepted,
+                self._create_empty_sample)
+
+        processes = [Process(target=work, args=args, daemon=self.daemon)
+                     for _ in range(self.n_procs)]
 
         for proc in processes:
             proc.start()
@@ -110,12 +119,14 @@ class MulticoreEvalParallelSampler(MultiCoreSampler):
         # make sure all results are collected
         # and the queue is emptied to prevent deadlocks
         n_done = 0
-        while n_done < len(processes):
-            val = get_if_worker_healthy(processes, queue)
-            if val == DONE:
-                n_done += 1
-            else:
-                id_results.append(val)
+        with jabbar(total=n, enable=show_progress, keep=False) as bar:
+            while n_done < len(processes):
+                val = get_if_worker_healthy(processes, queue)
+                if val == DONE:
+                    n_done += 1
+                else:
+                    id_results.append(val)
+                    bar.inc()
 
         for proc in processes:
             proc.join()
